require 'rubygems'
require 'minitest/autorun'
require 'shoulda'
require 'mocha'
require File.dirname(__FILE__)+'/../lib/packable'

class Minitest::Test
end
